%global emacs_lispdir %{_datadir}/emacs/site-lisp
%global pythonver %(python -c 'import sys;print ".".join(map(str, sys.version_info[:2]))')

%define pythonname Python-2.7.6
%define docutilsname docutils-0.11
%if "%{pythonver}" != "2.7"

%define hgpyprefix /usr/python-hg

# byte compilation will fail on some some Python /test/ files
%global _python_bytecompile_errors_terminate_build 0

%endif

Summary: A fast, lightweight Source Control Management system
Name: mercurial
Version: 3.0
Release: rc
License: GPLv2+
Group: Development/Tools
URL: http://mercurial.selenic.com/
Source0: http://mercurial.selenic.com/release/%{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

# From the README:
#
#   Note: some distributions fails to include bits of distutils by
#   default, you'll need python-dev to install. You'll also need a C
#   compiler and a 3-way merge tool like merge, tkdiff, or kdiff3.
#
# python-devel provides an adequate python-dev.  The merge tool is a
# run-time dependency.
#
BuildRequires: python >= 2.4, make, gcc, gettext
%if 1 == 1
BuildRequires: readline-devel, openssl-devel, ncurses-devel, zlib-devel, bzip2-devel
Source1: %{pythonname}.tgz
Source2: %{docutilsname}.tar.gz
%else
BuildRequires: python-devel, python-docutils >= 0.5
%endif
Provides: hg = %{version}-%{release}
Requires: python >= 2.4
# The hgk extension uses the wish tcl interpreter, but we don't enforce it
#Requires: tk

%description
Mercurial is a fast, lightweight source control management system designed
for efficient handling of very large distributed projects.

%prep
%if "%{?hgpyprefix}"

%setup -q -a1 -a2

# despite the comments in cgi.py, we do this to prevent rpmdeps from picking /usr/local/bin/python up
sed -i '1c#! /usr/bin/env python' %{pythonname}/Lib/cgi.py

%else

%setup -q

%endif

%build
%if "%{?hgpyprefix}"

PYPATH=$PWD/%{pythonname}
cd $PYPATH
./configure --prefix=%{hgpyprefix}
make all %{?_smp_mflags}
cd -

cd %{docutilsname}
LD_LIBRARY_PATH=$PYPATH $PYPATH/python setup.py build
cd -

# verify Python environment
LD_LIBRARY_PATH=$PYPATH PYTHONPATH=$PWD/%{docutilsname} $PYPATH/python -c 'import sys, zlib, bz2, ssl, curses, readline'

PATH=$PYPATH:$PATH LD_LIBRARY_PATH=$PYPATH CFLAGS="-L $PYPATH" PYTHONPATH=$PWD/%{docutilsname} make all

%else

make all

%endif

%install
rm -rf $RPM_BUILD_ROOT

%if "%{?hgpyprefix}"

PYPATH=$PWD/%{pythonname}
cd $PYPATH
make install DESTDIR=$RPM_BUILD_ROOT
# these .as are not necessary and they are readonly and strip fails - kill them!
rm -f %{buildroot}%{hgpyprefix}/lib/{,python2.*/config}/libpython2.*.a
cd -

cd %{docutilsname}
LD_LIBRARY_PATH=$PYPATH $PYPATH/python setup.py install --root="$RPM_BUILD_ROOT" #--prefix="$(PREFIX)"
cd -

PATH=$PYPATH:$PATH LD_LIBRARY_PATH=$PYPATH make install DESTDIR=$RPM_BUILD_ROOT PREFIX=%{hgpyprefix} MANDIR=%{_mandir}
mkdir -p $RPM_BUILD_ROOT%{_bindir}
( cd $RPM_BUILD_ROOT%{_bindir}/ && ln -s ../..%{hgpyprefix}/bin/python2.? ../..%{hgpyprefix}/bin/hg . )
%else

make install DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} MANDIR=%{_mandir}

%endif

install -m 755 contrib/hgk $RPM_BUILD_ROOT%{_bindir}/
install -m 755 contrib/hg-ssh $RPM_BUILD_ROOT%{_bindir}/

bash_completion_dir=$RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d
mkdir -p $bash_completion_dir
install -m 644 contrib/bash_completion $bash_completion_dir/mercurial.sh

zsh_completion_dir=$RPM_BUILD_ROOT%{_datadir}/zsh/site-functions
mkdir -p $zsh_completion_dir
install -m 644 contrib/zsh_completion $zsh_completion_dir/_mercurial

mkdir -p $RPM_BUILD_ROOT%{emacs_lispdir}
install -m 644 contrib/mercurial.el $RPM_BUILD_ROOT%{emacs_lispdir}/
install -m 644 contrib/mq.el $RPM_BUILD_ROOT%{emacs_lispdir}/

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/mercurial/hgrc.d
install -m 644 contrib/mergetools.hgrc $RPM_BUILD_ROOT%{_sysconfdir}/mercurial/hgrc.d/mergetools.rc

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc CONTRIBUTORS COPYING doc/README doc/hg*.txt doc/hg*.html *.cgi contrib/*.fcgi
%doc %attr(644,root,root) %{_mandir}/man?/hg*
%doc %attr(644,root,root) contrib/*.svg contrib/sample.hgrc
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions/
%{_datadir}/zsh/site-functions/_mercurial
%dir %{_datadir}/emacs/site-lisp/
%{_datadir}/emacs/site-lisp/mercurial.el
%{_datadir}/emacs/site-lisp/mq.el
%{_bindir}/hg
%{_bindir}/hgk
%{_bindir}/hg-ssh
%dir %{_sysconfdir}/bash_completion.d/
%config(noreplace) %{_sysconfdir}/bash_completion.d/mercurial.sh
%dir %{_sysconfdir}/mercurial
%dir %{_sysconfdir}/mercurial/hgrc.d
%config(noreplace) %{_sysconfdir}/mercurial/hgrc.d/mergetools.rc
%if "%{?hgpyprefix}"
%{_bindir}/python2.?
%{hgpyprefix}
%else
%if "%{?pythonver}" != "2.4"
%{_libdir}/python%{pythonver}/site-packages/%{name}-*-py%{pythonver}.egg-info
%endif
%{_libdir}/python%{pythonver}/site-packages/%{name}
%{_libdir}/python%{pythonver}/site-packages/hgext
%endif

%changelog
* Thu Apr 17 2014 Matt Mackall <mpm@selenic.com>
- Added tag 3.0-rc for changeset 564f55b25122

* Tue Apr 01 2014 Matt Mackall <mpm@selenic.com>
- Added tag 2.9.2 for changeset 3f83fc5cfe71

* Sat Mar 01 2014 Matt Mackall <mpm@selenic.com>
- Added tag 2.9.1 for changeset b96cb15ec9e0

* Sat Feb 01 2014 Matt Mackall <mpm@selenic.com>
- Added tag 2.9 for changeset 3cec5134e9c4

* Tue Jan 21 2014 Matt Mackall <mpm@selenic.com>
- Added tag 2.9-rc for changeset 8862469e16f9

* Wed Jan 01 2014 Matt Mackall <mpm@selenic.com>
- Added tag 2.8.2 for changeset ca387377df7a

* Sun Dec 01 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.8.1 for changeset 209e04a06467

* Fri Nov 01 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.8 for changeset d825e4025e39

* Sun Oct 20 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.8-rc for changeset 1596f2d8f242

* Tue Oct 01 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.7.2 for changeset e7fa36d2ad3a

* Tue Sep 03 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.7.1 for changeset 335a558f81dc

* Thu Aug 01 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.7 for changeset f37b5a17e6a0

* Fri Jul 26 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.7-rc for changeset f0d7721d7322

* Mon Jul 01 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.6.3 for changeset 009794acc6e3

* Sat Jun 01 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.6.2 for changeset cceaf7af4c9e

* Tue May 14 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.6.1 for changeset ddc7a6be2021

* Wed May 01 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.6 for changeset 23f785b38af3

* Thu Apr 18 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.6-rc for changeset 292cd385856d

* Thu Apr 04 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.5.4 for changeset 8a7bd2dccd44

* Tue Apr 02 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.5.3 for changeset 50c922c1b514

* Thu Feb 28 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.5.2 for changeset 5b7175377bab

* Fri Feb 08 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.5.1 for changeset 7511d4df752e

* Fri Feb 01 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.5 for changeset a6088c05e43a

* Sat Jan 19 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.5-rc for changeset f5fbe15ca744

* Wed Jan 02 2013 Matt Mackall <mpm@selenic.com>
- Added tag 2.4.2 for changeset a4765077b65e

* Mon Dec 03 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.4.1 for changeset 0c10cf819146

* Thu Nov 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.4 for changeset 195ad823b5d5

* Fri Oct 19 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.4-rc for changeset d118a4f4fd16

* Mon Oct 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.3.2 for changeset b3f0f9a39c4e

* Sat Sep 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.3.1 for changeset 072209ae4ddb

* Thu Aug 02 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.3 for changeset 7f5094bb3f42

* Wed Jul 18 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.3-rc for changeset a06e2681dd17

* Sun Jul 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.2.3 for changeset b013baa3898e

* Fri Jun 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.2.2 for changeset 85a358df5bbb

* Thu May 03 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.2.1 for changeset 5983de86462c

* Tue May 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.2 for changeset 00182b3d0879

* Wed Apr 18 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.2-rc for changeset d9e2f09d5488

* Sun Apr 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.1.2 for changeset b9bd95e61b49

* Thu Mar 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.1.1 for changeset 53e2cd303ecf

* Wed Feb 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.1 for changeset 2aa5b51f310f

* Fri Jan 20 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.1-rc for changeset db33555eafea

* Sun Jan 01 2012 Matt Mackall <mpm@selenic.com>
- Added tag 2.0.2 for changeset 634404392449

* Thu Dec 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 2.0.1 for changeset 195dbd1cef0c

* Tue Nov 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 2.0 for changeset 41453d55b481

* Sun Oct 16 2011 Matt Mackall <mpm@selenic.com>
- fix bad tag for 2.0-rc

* Sat Oct 15 2011 Matt Mackall <mpm@selenic.com>
- Added tag 2.0-rc for changeset fccd350acf79

* Sat Oct 15 2011 Matt Mackall <mpm@selenic.com>
- Added tag 2.0-rc for changeset 384082750f2c

* Sat Oct 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.9.3 for changeset 351a9292e430

* Fri Aug 26 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.9.2 for changeset d629f1e89021

* Mon Aug 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.9.1 for changeset 4a43e23b8c55

* Fri Jul 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.9 for changeset de9eb6b1da4f

* Wed Jun 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.8.4 for changeset 733af5d9f6b2

* Sun May 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.8.3 for changeset 3cb1e95676ad

* Fri Apr 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.8.2 for changeset b032bec2c0a6

* Thu Mar 10 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.8.1 for changeset aa1f3be38ab1

* Tue Mar 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.8 for changeset 2616325766e3

* Tue Feb 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.7.5 for changeset 2b2155623ee2

* Tue Feb 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.7.4 for changeset a6c855c32ea0

* Sat Jan 01 2011 Matt Mackall <mpm@selenic.com>
- Added tag 1.7.3 for changeset e3bf16703e26

* Wed Dec 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.7.2 for changeset 6aff4f144ad3

* Mon Nov 15 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.7.1 for changeset 4438875ec01b

* Mon Nov 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.7 for changeset 333421b9e0f9

* Fri Oct 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.6.4 for changeset 93d8bff78c96

* Thu Aug 26 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.6.3 for changeset ff5cec76b1c5

* Mon Aug 02 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.6.2 for changeset c00f03a4982e

* Sun Aug 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.6.1 for changeset bf1774d95bde

* Thu Jul 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.6 for changeset f786fc4b8764

* Tue Jun 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.5.4 for changeset 24fe2629c6fd

* Thu May 13 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.5.3 for changeset fdcf80f26604

* Sat May 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.5.2 for changeset 39f725929f0c

* Thu Apr 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.5.1 for changeset 2b01dab59416

* Fri Mar 05 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.5 for changeset ff2704a8ded3

* Mon Feb 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.4.3 for changeset 4aa619c4c2c0

* Fri Jan 01 2010 Matt Mackall <mpm@selenic.com>
- Added tag 1.4.2 for changeset 296a0b14a686

* Tue Dec 01 2009 Matt Mackall <mpm@selenic.com>
- Added tag 1.4.1 for changeset 439d7ea6fe3a

* Mon Nov 16 2009 Matt Mackall <mpm@selenic.com>
- Added tag 1.4 for changeset 31ec469f9b55

* Thu Jul 23 2009 Matt Mackall <mpm@selenic.com>
- Added tag 1.3.1 for changeset 3ef6c14a1e8e

* Wed Jul 01 2009 Matt Mackall <mpm@selenic.com>
- Added tag 1.3 for changeset 196d40e7c885

* Fri Mar 20 2009 Matt Mackall <mpm@selenic.com>
- Added tag 1.2.1 for changeset 02981000012e

* Wed Mar 04 2009 Matt Mackall <mpm@selenic.com>
- Added tag 1.2 for changeset 11efa41037e2

* Wed Dec 31 2008 Matt Mackall <mpm@selenic.com>
- Added tag 1.1.2 for changeset 11a4eb81fb4f

* Sat Dec 20 2008 Matt Mackall <mpm@selenic.com>
- Added tag 1.1.1 for changeset 3773e510d433

* Tue Dec 02 2008 Matt Mackall <mpm@selenic.com>
- Added tag 1.1 for changeset 2a67430f92f1

* Wed Aug 13 2008 Matt Mackall <mpm@selenic.com>
- Added tag 1.0.2 for changeset d2375bbee6d4

* Thu May 22 2008 Matt Mackall <mpm@selenic.com>
- Added tag 1.0.1 for changeset d5cbbe2c49ce

* Mon Mar 24 2008 Matt Mackall <mpm@selenic.com>
- Added tag 1.0 for changeset bae2e9c838e9

* Fri Oct 19 2007 Matt Mackall <mpm@selenic.com>
- Added tag 0.9.5 for changeset 23889160905a

* Mon Jun 25 2007 Matt Mackall <mpm@selenic.com>
- Added tag 0.9.4 for changeset fb4b6d5fe100

* Sun Dec 17 2006 Matt Mackall <mpm@selenic.com>
- Added tag 0.9.3 for changeset 27230c29bfec

* Sun Dec 10 2006 Matt Mackall <mpm@selenic.com>
- Added tag 0.9.2 for changeset 36a957364b1b

* Mon Jul 24 2006 Matt Mackall <mpm@selenic.com>
- Added tag 0.9.1 for changeset 2be3001847cb18a23c403439d9e7d0ace30804e9

* Wed May 10 2006 Matt Mackall <mpm@selenic.com>
- Added tag 0.9 for changeset 35fb62a3a673d5322f6274a44ba6456e5e4b3b37

* Fri Apr 07 2006 Matt Mackall <mpm@selenic.com>
- Added tag 0.8.1 for changeset 6a03cff2b0f5d30281e6addefe96b993582f2eac

* Mon Jan 30 2006 Matt Mackall <mpm@selenic.com>
- Added tag 0.8 for changeset 3a56574f329a368d645853e0f9e09472aee62349

* Fri Sep 16 2005 mpm@selenic.com
- Added tag 0.7 for changeset 979c049974485125e1f9357f6bbe9c1b548a64c3

* Sat Aug 20 2005 mpm@selenic.com
- Merge with jeffpc

* Sat Aug 20 2005 mpm@selenic.com
- Added tag 0.6c for changeset eac9c8efcd9bd8244e72fb6821f769f450457a32

* Mon Jul 11 2005 Matt Mackall <mpm@selenic.com>
- Added tag 0.6b for changeset 4ccf3de52989b14c3d84e1097f59e39a992e00bd

* Fri Jun 24 2005 mpm@selenic.com
- Added tag 0.6 for changeset 12e0fdbc57a0be78f0e817fd1d170a3615cd35da

* Mon May 30 2005 mpm@selenic.com
- Update tags

* Sat May 28 2005 mpm@selenic.com
- Add tag for 0.5

* Fri May 13 2005 mpm@selenic.com
- Beginnings of changelog tagging

